==> zeroc-ice_3.4.2.orig.tar.gz: Ice-3.4.2/cpp/src/IceStorm/SqlDB/SqlDB.h <==
// **********************************************************************
//
// Copyright (c) 2003-2011 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

#ifndef SQL_DATABASE_CACHE_H
#define SQL_DATABASE_CACHE_H

#include <IceStorm/DB.h>

#include <IceStorm/SqlDB/SqlLLU.h>
#include <IceStorm/SqlDB/SqlSubscriberMap.h>

#include <QtCore/QCoreApplication>

namespace IceStorm
{

class SqlDatabaseCache : public SqlDB::DatabaseCache, public DatabaseCache
{
public:

    SqlDatabaseCache(const Ice::CommunicatorPtr&, const std::string&, const std::string&,
                     const std::string&, int, const std::string&, const std::string&, const std::string&);
    virtual ~SqlDatabaseCache();

    virtual LLUWrapperPtr getLLU(const IceDB::DatabaseConnectionPtr&);
    virtual SubscribersWrapperPtr getSubscribers(const IceDB::DatabaseConnectionPtr&);
    
private:

    const SqlLLUPtr _llu;
    const SqlSubscriberMapPtr _subscribers;
};
typedef IceUtil::Handle<SqlDatabaseCache> SqlDatabaseCachePtr;

class SqlDBPlugin : public DatabasePlugin
{
public:

    SqlDBPlugin(const Ice::CommunicatorPtr&, int, char**);
    virtual ~SqlDBPlugin();

    virtual void initialize();
    virtual void destroy();
    
    DatabaseCachePtr getDatabaseCache(const std::string&);

private:

    const Ice::CommunicatorPtr _communicator;
};

}

#endif

==> zeroc-ice_3.5.1.orig.tar.gz: Ice-3.5.1/cpp/src/IceStorm/SqlDB/SqlDB.h <==
// **********************************************************************
//
// Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
//
// This copy of Ice is licensed to you under the terms described in the
// ICE_LICENSE file included in this distribution.
//
// **********************************************************************

#ifndef SQL_DATABASE_CACHE_H
#define SQL_DATABASE_CACHE_H

#include <IceStorm/DB.h>

#include <IceStorm/SqlDB/SqlLLU.h>
#include <IceStorm/SqlDB/SqlSubscriberMap.h>

#include <QtCore/QCoreApplication>

namespace IceStorm
{

class SqlConnectionPool : public SqlDB::ConnectionPool, public ConnectionPool
{
public:

    SqlConnectionPool(const Ice::CommunicatorPtr&, const std::string&, const std::string&,
                     const std::string&, int, const std::string&, const std::string&, const std::string&, 
                     const std::string&);
    virtual ~SqlConnectionPool();

    virtual LLUWrapperPtr getLLU(const IceDB::DatabaseConnectionPtr&);
    virtual SubscribersWrapperPtr getSubscribers(const IceDB::DatabaseConnectionPtr&);
    
private:

    const SqlLLUPtr _llu;
    const SqlSubscriberMapPtr _subscribers;
};
typedef IceUtil::Handle<SqlConnectionPool> SqlConnectionPoolPtr;

class SqlDBPlugin : public DatabasePlugin
{
public:

    SqlDBPlugin(const Ice::CommunicatorPtr&, int, char**);
    virtual ~SqlDBPlugin();

    virtual void initialize();
    virtual void destroy();
    
    ConnectionPoolPtr getConnectionPool(const std::string&);

private:

    const Ice::CommunicatorPtr _communicator;
};

}

#endif
